summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsbindingplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsbindingplugin.h')
-rw-r--r--kjsembed/jsbindingplugin.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/jsbindingplugin.h b/kjsembed/jsbindingplugin.h
index 6755621b..fb7d6361 100644
--- a/kjsembed/jsbindingplugin.h
+++ b/kjsembed/jsbindingplugin.h
@@ -21,7 +21,7 @@
#ifndef KJSEMBEDBINDINGPLUGIN_H
#define KJSEMBEDBINDINGPLUGIN_H
-#include <qobject.h>
+#include <tqobject.h>
#include <kjs/interpreter.h>
#include <kjs/identifier.h>
#include <kjs/types.h>
@@ -39,14 +39,14 @@ namespace KJSEmbed {
* @author Ian Reinhart Geiser, geiseri@kde.org
* @version $Id$
*/
- class KJSEMBED_EXPORT JSBindingPlugin : public QObject {
+ class KJSEMBED_EXPORT JSBindingPlugin : public TQObject {
Q_OBJECT
public:
- JSBindingPlugin( QObject *parent, const char *name, const QStringList &args );
+ JSBindingPlugin( TQObject *parent, const char *name, const TQStringList &args );
virtual ~JSBindingPlugin();
/**
* This method is called by the KJSFactory to bootstrap the plugin.
* Plugin developers will want to use this method to create their QObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*
* The value returned from ths function is the KJS::Object that represents the
@@ -39,14 +39,14 @@ namespace KJSEmbed {
/**
* This method is called by the KJSFactory to bootstrap the plugin.
- * Plugin developers will want to use this method to create their QObject binding,
+ * Plugin developers will want to use this method to create their TQObject binding,
* or call their addBindings() method in their JSOpaque proxy or JSValueProxy.
*